import type { GlslInfoLogArray } from "./glsl-info-log";
import type { SpglslLanguage, SpglslCompileMode, SpglslPrecision } from "./spglsl-enums";
import type { SpglslResourceLimits } from "./spglsl-resource-limits";
export interface SpglslAngleCompileOptions {
    compileMode?: SpglslCompileMode;
    language?: string;
    customData?: unknown;
    resourceLimits?: Partial<SpglslResourceLimits>;
    floatPrecision?: SpglslPrecision;
    intPrecision?: SpglslPrecision;
    minify?: boolean;
    mangle?: boolean;
    beautify?: boolean;
    recordConstantPrecision?: boolean;
}
export interface SpglslAngleCompileInput extends SpglslAngleCompileOptions {
    mainFilePath?: string;
    mainSourceCode: string;
    cwd?: string;
}
export declare class SpglslAngleCompileResult {
    compileMode: SpglslCompileMode;
    mainFilePath: string;
    language: SpglslLanguage;
    outputVersion: number;
    valid: boolean;
    customData: unknown | undefined;
    /** The time it took to compile, in milliseconds */
    duration: number;
    /** The source code input */
    source: string;
    /** The output or null if there is no output */
    output: string | null;
    infoLog: GlslInfoLogArray;
    floatPrecision: SpglslPrecision;
    intPrecision: SpglslPrecision;
    minify: boolean;
    mangle: boolean;
    beautify: boolean;
    recordConstantPrecision: boolean;
    cwd: string | undefined;
    constructor();
}
export declare function spglslAngleCompile(input: Readonly<SpglslAngleCompileInput>): Promise<SpglslAngleCompileResult>;
export declare class SpglslAngleCompileError extends Error {
    code: "SPGLSL_ERR";
    spglslResult: SpglslAngleCompileResult;
    filePath: string;
    durationMs: number;
    get infoLog(): GlslInfoLogArray;
    constructor(spglslResult: SpglslAngleCompileResult, message?: string, caller?: Function);
}
export declare function inspectSpglslAngleCompileResult(result: SpglslAngleCompileResult): string;
